==> react-native-digitcamera-1.1.5.tgz: package/src/Screens/InCorrectImages.js <==
import React, { useEffect, useRef, useState } from "react";
import { StyleSheet, View, Image, Text, StatusBar, FlatList } from "react-native";
import {
  SCREEN_HEIGHT,
  SCREEN_WIDTH,
} from "react-native-digitcamera/src/common/Constants";
import { translate } from "react-native-digitcamera/src/common/localize/i18n";
import Orientation from "../../../react-native-orientation";
import Geolocation from "@react-native-community/geolocation";
import { getTimeZone } from "react-native-digitcamera/node_modules/react-native-localize";
import { TouchableOpacity } from "react-native-gesture-handler";
import RNFetchBlob from "rn-fetch-blob";
import { SELFSURVEYSERVICE_DOCUMENT_URL } from "react-native-digitcamera/src/Api/ApiUrls";
import ViewShot, { captureRef } from "react-native-view-shot";
import VideoPlayer from 'react-native-video-player'
import Header from "./Header"
import { PrimaryButton } from "../common/ThemedComponents";
  const retake = require("../common/Image/retake.png");
  const proceed = require("../common/Image/proceed.png");
  const incorrectImageData = [
        {
      image: proceed,
      heading:
        "To help you click the correct image, simply refer to the image and instructions given at each step and you will be done in no time!",
      subHeading:"This image is taken from a different side or is of a different object",
    },
        {
      image: proceed,
      heading:
        "To help you click the correct image, simply refer to the image and instructions given at each step and you will be done in no time!",
      subHeading:"This image is taken from a different side or is of a different object",
    },
        {
      image: proceed,
      heading:
        "To help you click the correct image, simply refer to the image and instructions given at each step and you will be done in no time!",
      subHeading:"This image is taken from a different side or is of a different object",
    },
        {
      image: proceed,
      heading:
        "To help you click the correct image, simply refer to the image and instructions given at each step and you will be done in no time!",
      subHeading:"This image is taken from a different side or is of a different object",
    },
    {
      image: proceed,
      heading:
        "To help you click the correct image, simply refer to the image and instructions given at each step and you will be done in no time!",
      subHeading:"This image is taken from a different side or is of a different object",
    },
  ];
const PreviewImage = ({ navigation, route }) => {
  const imageref = useRef();
  const [incorrectImageCount, SetIncorrectImageCount] = useState("3");

//   const {
//     ImageData,
//     ext,
//     DocumentImageName,
//     activityId,
//     activityTypeId,
//     webUserId,
//   } = route.params;



  useEffect(() => {

  }, []);
  
  const renderItem=({item,index})=>{
      return(
          <View>
          <View style={styles.listView}>
    {/* Image View */}
    <View style={styles.imageView}>
        <Image
        source={item.image}
        style={{alignSelf:"center",width:SCREEN_WIDTH/2.7,height:SCREEN_WIDTH/2.9,resizeMode:"contain"}}
        />
    </View>
    {/* Blank View */}
    <View style={styles.blankView}></View>
    {/* Text View */}
    <View style={styles.textView}>
        <Text style={styles.heading}>{item.heading}</Text>
        <Text style={styles.subHeadingText}>{item.subHeading}</Text>
    </View>
</View>
<View style={styles.divider}></View>
</View>
      )
  }
  return (
    <View style={styles.main}>
      <StatusBar hidden={true} />
      <Header/>
      {/* Document list  */}
     <View style={styles.subMainView}>
<Text style={styles.oopsTitleText}>{translate("Oops!  ")}<Text style={{fontSize:20,color:"#000000"}}>{incorrectImageCount}{" "}{translate("Incorrect photos")}</Text></Text>
<Text style={styles.subText}>{translate("Please upload the photo again! The photo uploaded is incorrect Please follow the instructions and capture it again")}</Text>

   <FlatList
              data={incorrectImageData}
              keyExtractor={(item, index) => index.toString()}
              renderItem={renderItem}
              maxToRenderPerBatch={100}
              updateCellsBatchingPeriod={1000}
            />
     </View>
     {/* button view */}
     <View style={styles.buttonView}>
<PrimaryButton>
{translate("Retake")}
</PrimaryButton>
     </View>
    </View>
  );
};
export default PreviewImage;

const styles = StyleSheet.create({
  main: {
    flex: 1,
  },
  subMainView:{
      flex:0.9,
      margin:24,
  },
  buttonView:{
      flex:0.1,
      marginLeft:24,
      marginRight:24,
      justifyContent:"center"
  },
  oopsTitleText:{
      fontFamily:"Muli-ExtraBold",
      fontSize:20,
      color:"red",
      marginBottom:10
  },
  titleText:{
        fontFamily:"Muli-ExtraBold",
      fontSize:20,
  },
  subText:{
      fontSize:16,
      fontFamily:"Muli-Regular",
      marginBottom:24
  },
  imageView:{
flex:0.4,
justifyContent:"center",
borderColor:"#DDDDDD",
borderWidth:1,
borderRadius:8
  },
  listView:{
      flex:1,
      flexDirection:"row"
  },
  blankView:{
      flex:0.05,
  },
  textView:{
      flex:0.55,
      justifyContent:"center"
  },
  divider:{
      width:SCREEN_WIDTH,
      height:1,
      borderWidth:1,
      marginTop:17,
      marginBottom:17,
      borderColor:"#DDDDDD"
  },
  heading:{
      fontSize:16,
      fontFamily:"Muli-Bold",
      marginBottom:10,
  },
  subHeadingText:{
        fontSize:13,
      fontFamily:"Muli-Regular",
      color:"#444444"
  }
});

==> react-native-digitcamera-1.1.6.tgz: package/src/Screens/InCorrectImages.js <==
import React, { useEffect, useRef, useState } from "react";
import { StyleSheet, View, Image, Text, StatusBar, FlatList } from "react-native";
import {
  SCREEN_HEIGHT,
  SCREEN_WIDTH,
} from "react-native-digitcamera/src/common/Constants";
import { translate } from "react-native-digitcamera/src/common/localize/i18n";
import Orientation from "../../../react-native-orientation";
import Geolocation from "@react-native-community/geolocation";
import { getTimeZone } from "react-native-digitcamera/node_modules/react-native-localize";
import { TouchableOpacity } from "react-native-gesture-handler";
import RNFetchBlob from "rn-fetch-blob";
import { SELFSURVEYSERVICE_DOCUMENT_URL } from "react-native-digitcamera/src/Api/ApiUrls";
import ViewShot, { captureRef } from "react-native-view-shot";
import VideoPlayer from 'react-native-video-player'
import Header from "./Header"
import { PrimaryButton } from "../common/ThemedComponents";
import { useSelector, useDispatch } from 'react-redux';

  const retake = require("../common/Image/retake.png");
  const proceed = require("../common/Image/proceed.png");
const InCorrectImages = ({ navigation, route }) => {
  const imageref = useRef();
  const [incorrectImageCount, SetIncorrectImageCount] = useState("3");
   const dispatch = useDispatch();
  const RetryCountData = useSelector(state => state.RetryCountData);
    const RetryImageData  = useSelector(state => state.RetryImageData);

  useEffect(() => {
 let unsubscribe = navigation.addListener("focus", () => {
      Orientation.lockToPortrait();
    });
    return () => {
      unsubscribe();
    };
  }, []);
  
  const addDataToredux=()=>{
      dispatch({
          type: 'RETRY_COUNT',
          payload: {
        retryCount:Number(RetryCountData.retryCountInfo.retryCount)+1,
        index:0,
        isAddNewImageData:true
          },
        });
console.log("Count ",RetryCountData);
              navigation.navigate("PI");
  }
  const renderItem=({item,index})=>{
    if(item.imagePath==""){
      //removed blank obj.
      return null
    }else{
      return(
          <View>
          <View style={styles.listView}>
    {/* Image View */}
    <View style={styles.imageView}>
        <Image
        source={{uri:item.imagePath}}
        style={{alignSelf:"center",width:SCREEN_WIDTH/2.7,height:SCREEN_WIDTH/2.9,resizeMode:"stretch"}}
        />
    </View>
    {/* Blank View */}
    <View style={styles.blankView}></View>
    {/* Text View */}
    <View style={styles.textView}>
        <Text style={styles.heading}>{item.title}</Text>
        <Text style={styles.subHeadingText}>{item.subTitle}</Text>
    </View>
</View>
<View style={styles.divider}></View>
</View>
      )
    }

  }
  return (
    <View style={styles.main}>
      <StatusBar hidden={true} />
      <Header/>
      {/* Document list  */}
     <View style={styles.subMainView}>
<Text style={styles.oopsTitleText}>{translate("Oops!  ")}<Text style={{fontSize:20,color:"#000000"}}>{RetryImageData.retryImageInfo.length}{" "}{translate("Incorrect photos")}</Text></Text>
<Text style={styles.subText}>{translate("Please upload the photo again! The photo uploaded is incorrect Please follow the instructions and capture it again")}</Text>

   <FlatList
              data={RetryImageData.retryImageInfo}
              keyExtractor={(item, index) => index.toString()}
              renderItem={renderItem}
              maxToRenderPerBatch={100}
              updateCellsBatchingPeriod={1000}
            />
     </View>
     {/* button view */}
     <View style={styles.buttonView}>
<PrimaryButton 
onPress={()=>{
  addDataToredux()
}}
>
{translate("Retake")}
</PrimaryButton>
     </View>
    </View>
  );
};
export default InCorrectImages;

const styles = StyleSheet.create({
  main: {
    flex: 1,
  },
  subMainView:{
      flex:0.9,
      margin:24,
  },
  buttonView:{
      flex:0.1,
      marginLeft:24,
      marginRight:24,
      justifyContent:"center"
  },
  oopsTitleText:{
      fontFamily:"Muli-ExtraBold",
      fontSize:20,
      color:"red",
      marginBottom:10
  },
  titleText:{
        fontFamily:"Muli-ExtraBold",
      fontSize:20,
  },
  subText:{
      fontSize:16,
      fontFamily:"Muli-Regular",
      marginBottom:24
  },
  imageView:{
flex:0.4,
justifyContent:"center",
borderColor:"#DDDDDD",
borderWidth:1,
borderRadius:8
  },
  listView:{
      flex:1,
      flexDirection:"row"
  },
  blankView:{
      flex:0.05,
  },
  textView:{
      flex:0.55,
      justifyContent:"center"
  },
  divider:{
      width:SCREEN_WIDTH,
      height:1,
      borderWidth:1,
      marginTop:17,
      marginBottom:17,
      borderColor:"#DDDDDD"
  },
  heading:{
      fontSize:16,
      fontFamily:"Muli-Bold",
      marginBottom:10,
  },
  subHeadingText:{
        fontSize:13,
      fontFamily:"Muli-Regular",
      color:"#444444"
  }
});
